# References List of references used in this documentation: 1. [nyaml GitHub repository](https://github.com/FAIRmat-NFDI/nyaml) 2. [NeXus-FAIRmat proposal](https://fairmat-nfdi.github.io/nexus_definitions/) 3. [FAIRmat-NeXus GitHub repository](https://github.com/FAIRmat-NFDI/nexus_definitions) 4. [NeXus official website](https://manual.nexusformat.org/index.html) 5. [NeXus paper by Könnecke et al.](https://doi.org/10.1107/S1600576714027575) 6. [XML 1.0](https://www.w3.org/TR/REC-xml/REC-xml-20081126.xml) 7. [nyaml](https://github.com/FAIRmat-NFDI/nyaml/tree/main) 8. [NeXus official website](https://www.nexusformat.org/) 9. [YAML](https://yaml.org/) 10. [lxml - XML and HTML with Python](https://lxml.de/) 11. [NeXus Manual](https://manual.nexusformat.org/user_manual.html)